#pragma once
#include "math.h"

class LowpassFilter
{
private:
	int order;
	double a0;
	double *lp;

public:
	LowpassFilter::LowpassFilter(int order)
	{	
		this->order = order;
		a0 = 0;
		lp = new double[order];
		reset();
	}

	LowpassFilter::~LowpassFilter()
	{
		delete[] lp;
	}

	void LowpassFilter::reset()
	{
		for(int i=0;i<order;i++)
		{
			lp[i]=0;	
		}
	}

	double LowpassFilter::process(double v)
	{
		for(int i=0;i<order;i++)
		{
			lp[i] += a0 * (v - lp[i]);
			v = lp[i];
		}
		return v;
	}

	void SetFrequency(double freq, double samplerate)
	{
		freq/=sqrt(-1.+pow(4.,1./order));
		a0 = 1.0 - exp(-2.0 *  3.1415926535897932 * freq / samplerate);
	}
};
